#include <bits/stdc++.h>
#include "cycles.h"

const int64_t MAX_N = 1e3 + 10;

#define myAssert(COND, MESSAGE) if (!(COND)) { std::cout << -1 << std::endl << MESSAGE << std::endl; exit(0); }

static const std::string CORRECT = "CORRECT";
static const std::string WRONG = "WRONG";
static const std::string PASSWORD = "gaiuvelavmaklvnaj";
static int64_t cnt = 0;
static std::vector<int> perm;
static int64_t n;
static std::mt19937_64 mt(134);

struct FastCounter
{
    struct Node
    {
        int sz = 1;
        int prio;
        Node* left = nullptr;
        Node* right = nullptr;
        Node* parent = nullptr;

        Node()
        {
            prio = mt();
        }

        void recompute()
        {
            sz = 1;
            if (left)
                sz += left->sz;
            if (right)
                sz += right->sz;
        }
    };

	std::vector<Node> mem;
    int cycleCount = 0;
    long long ops = 0;

    FastCounter(const std::vector<int>& perm)
    {
        mem.resize(perm.size());

		std::vector<bool> seen(perm.size(), false);
        for (int i = 0; i < perm.size(); i++)
        {
            if (!seen[i])
            {
                cycleCount++;

                Node *root = &mem[i];
                seen[i] = true;

                int cur = perm[i];
                while(!seen[cur])
                {
                    seen[cur] = true;
                    root = merge(root, &mem[cur]);
                    cur = perm[cur];
                }
            }
        }
    }

	std::pair<Node*, int> getRootAndPos(int idx)
    {
        Node* node = &mem[idx];
        int pos = 0;

        if (node->left)
            pos += node->left->sz;

        while(node->parent)
        {
            ops++;
            if (node == node->parent->right)
            {
                pos++;
                if (node->parent->left)
                    pos += node->parent->left->sz;
            }

            node = node->parent;
        }

        return {node, pos};
    }

    void pairSwap(int x, int y)
    {
        if (x == y)
            return;

        auto [xRoot, xPos] = getRootAndPos(x);
        auto [yRoot, yPos] = getRootAndPos(y);

        if (xRoot == yRoot)
        {
            assert(xPos != yPos);
            cycleCount++;

            if (yPos < xPos)
            {
				std::swap(xRoot, yRoot);
                std::swap(xPos, yPos);
            }
            auto [AB, C] = split(xRoot, yPos + 1);
            auto [A, B] = split(AB, xPos + 1);

            merge(A, C);
        }
        else
        {
            cycleCount--;

            auto [xA, xB] = split(xRoot, xPos + 1);
            auto [yA, yB] = split(yRoot, yPos + 1);

            Node* res = merge(xA, yB);
            res = merge(res, yA);
            res = merge(res, xB);
        }
    }

    int getCycles()
    {
        return cycleCount;
    }

	std::pair<Node*, Node*> split(Node* ver, int leftSize)
    {
        ops++;
        if (!ver)
            return {nullptr, nullptr};

        int leftSide = ((ver->left) ? ver->left->sz : 0) + 1;

        if (leftSide <= leftSize)
        {
            auto [rLeft, rRight] = split(ver->right, leftSize - leftSide);
            ver->right = rLeft;
            ver->recompute();
            if (rLeft)
                rLeft->parent = ver;
            if (rRight)
                rRight->parent = nullptr;
            return {ver, rRight};
        }
        else
        {
            auto [lLeft, lRight] = split(ver->left, leftSize);
            ver->left = lRight;
            ver->recompute();
            if (lLeft)
                lLeft->parent = nullptr;
            if (lRight)
                lRight->parent = ver;
            return {lLeft, ver};
        }
    }

    Node* merge(Node* left, Node* right)
    {
        ops++;
        if (!left || !right)
        {
            return left ? left : right;
        }

        if (left->prio > right->prio)
        {
            Node* merged = merge(left->right, right);

            left->right = merged;
            left->recompute();
            if (merged)
                merged->parent = left;
            return left;
        }
        else
        {
            Node* merged = merge(left, right->left);
            right->left = merged;
            right->recompute();
            if (merged)
                merged->parent = right;
            return right;
        }
    }
};

static FastCounter* counter;

int findPermCountSlow() {
	std::vector<bool> used(n, false);
	int64_t cntc = 0;
	for (int64_t i = 0; i < n; i ++) {
		if (used[i]) { continue; }
		int64_t curr = i; cntc ++;
		while (!used[curr]) {
			used[curr] = true;
			curr = perm[curr];
		}
	}
    return cntc;
}

int findPermCount() {
	return counter->getCycles();
}

const int64_t MAX_SWAPS = 10'000'000;

int performSwap(int i, int j) {
	cnt ++;
    myAssert(cnt <= MAX_SWAPS, "More than 1e7 queries");

	bool valid_swap = true;
    valid_swap &= (0 <= i && i < n);
    valid_swap &= (0 <= j && j < n);
    valid_swap &= (i != j);
	myAssert(valid_swap, "Your program tried to do an invalid swap.");

	counter->pairSwap(i, j); std::swap(perm[i], perm[j]);
	return counter->getCycles();
}

int main() {
	std::cin >> n;
	perm.resize(n);
	for (int64_t i = 0; i < n; i ++) { std::cin >> perm[i]; }
	counter = new FastCounter(perm);
	sortPermutation(n);
	if (findPermCount() != n) {
		std::cout << WRONG << std::endl;
	} else {
		std::cout << CORRECT << std::endl << n << " " << cnt << std::endl << PASSWORD << std::endl;
	}
	return 0;
}
